@@ -22,18 +22,15 @@
 
 #include <QDialog>
 
-namespace GrantleeThemeEditor
-{
+namespace GrantleeThemeEditor {
 class ConfigureWidget;
 }
 
-namespace Akonadi
-{
-class ContactEditor;
+namespace Akonadi {
+class AkonadiContactEditor;
 }
 
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class PlainTextEditorWidget;
 }
 class ContactPrintThemeConfigureDialog : public QDialog
@@ -51,7 +48,7 @@ private:
     void slotDefaultClicked();
     GrantleeThemeEditor::ConfigureWidget *mConfigureWidget;
     KPIMTextEdit::PlainTextEditorWidget *mDefaultTemplate;
-    Akonadi::ContactEditor *mDefaultContact;
+    Akonadi::AkonadiContactEditor *mDefaultContact;
 };
 
 #endif
