@@ -26,8 +26,7 @@ class ThemeTemplateWidget;
 class EditorWidget;
 class QSplitter;
 class ContactPrintThemePreview;
-namespace GrantleeThemeEditor
-{
+namespace GrantleeThemeEditor {
 class EditorWidget;
 }
 
