@@ -21,18 +21,15 @@
 
 #include <QDialog>
 
-namespace GrantleeThemeEditor
-{
+namespace GrantleeThemeEditor {
 class ConfigureWidget;
 }
 
-namespace Akonadi
-{
-class ContactEditor;
+namespace Akonadi {
+class AkonadiContactEditor;
 }
 
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class PlainTextEditorWidget;
 }
 class ContactConfigureDialog : public QDialog
@@ -50,7 +47,7 @@ private:
     void slotOkClicked();
     GrantleeThemeEditor::ConfigureWidget *mConfigureWidget;
     KPIMTextEdit::PlainTextEditorWidget *mDefaultTemplate;
-    Akonadi::ContactEditor *mDefaultContact;
+    Akonadi::AkonadiContactEditor *mDefaultContact;
 };
 
 #endif // CONTACTCONFIGUREDIALOG_H
