@@ -49,7 +49,6 @@ GrantleePlainTextEditor::GrantleePlainTextEditor(QWidget *parent)
 
 GrantleePlainTextEditor::~GrantleePlainTextEditor()
 {
-
 }
 
 void GrantleePlainTextEditor::initCompleter()
@@ -59,8 +58,6 @@ void GrantleePlainTextEditor::initCompleter()
 
 void GrantleePlainTextEditor::createCompleterList(const QStringList &extraCompletion)
 {
-    QStringList listWord;
-    listWord << extraCompletion;
     mTextEditorCompleter->setCompleterStringList(extraCompletion);
 }
 
@@ -82,4 +79,3 @@ void GrantleePlainTextEditor::keyPressEvent(QKeyEvent *e)
     KPIMTextEdit::PlainTextEditor::keyPressEvent(e);
     mTextEditorCompleter->completeText();
 }
-
