@@ -33,25 +33,25 @@ class GrantleeThemeEditor::NewThemeDialogPrivate
 {
 public:
     NewThemeDialogPrivate()
-        : mThemeName(nullptr),
-          mUrlRequester(nullptr),
-          mOkButton(nullptr)
+        : mThemeName(nullptr)
+        , mUrlRequester(nullptr)
+        , mOkButton(nullptr)
     {
-
     }
+
     KLineEdit *mThemeName;
     KUrlRequester *mUrlRequester;
     QPushButton *mOkButton;
 };
 NewThemeDialog::NewThemeDialog(QWidget *parent)
-    : QDialog(parent),
-      d(new GrantleeThemeEditor::NewThemeDialogPrivate)
+    : QDialog(parent)
+    , d(new GrantleeThemeEditor::NewThemeDialogPrivate)
 {
     setWindowTitle(i18n("New Theme"));
 
     QWidget *w = new QWidget;
 
-    QVBoxLayout *lay = new QVBoxLayout;
+    QVBoxLayout *lay = new QVBoxLayout(w);
     lay->setMargin(0);
 
     QLabel *lab = new QLabel(i18n("Theme name:"));
@@ -71,12 +71,10 @@ NewThemeDialog::NewThemeDialog(QWidget *parent)
     connect(d->mUrlRequester->lineEdit(), &KLineEdit::textChanged, this, &NewThemeDialog::slotUpdateOkButton);
     lay->addWidget(d->mUrlRequester);
 
-    w->setLayout(lay);
-
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(w);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     d->mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     d->mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &NewThemeDialog::accept);
@@ -116,4 +114,3 @@ void NewThemeDialog::slotUpdateOkButton()
     d->mOkButton->setEnabled(!d->mUrlRequester->lineEdit()->text().trimmed().isEmpty()
                              && !d->mThemeName->text().trimmed().isEmpty());
 }
-
